
# Rules for eltdev machine.
class eltdev inherits eltminimal {

	# In a separate file (autogenerated if we want) for sake of clarity
	include eltdev::sysrpms

	# Fix contents of file containing the role of the machine
	File_line["elt-role-variable"] {
		line => "export ELT_ROLE=ELTDEV",
	}
	

	if $elt_dm == 'yes' or $elt_dm == 'YES' {
	# Lightdm as default greeter, with XDCMP enabled
          notice('Installing/checking display-manager')
	  service { "lightdm":
                ensure => "running",
		enable => "true",
	  }
	}
	else {
          notice('Installing/checking no-graph ELTDEV station')
	  service { "lightdm":
                ensure => "stopped",
		enable => "false",
	  }
	}

	# ELTDEV-299 enable nix-deamon by default
        service { "nix-daemon":
                ensure => "running",
                enable => "true",
		require => Augeas["selinux"],
        }

        # ELTDEV-674: Nix currently needs a few more directories. Some of these (ie. SVN) will be
        # likely removed in the future. GID 4717 corresponds to reserved nixbld group
        Package <| |> -> file { [ "/svn", "/svn/auth", "/var/lib/empty", "/eso", "/eso/internal" ]:
                ensure => "directory",
                owner => "root",
                group => "4717",
                mode => "0775",
        }


	# Graphical login as default and XDMCP enabled
	file { "/etc/systemd/system/default.target":
		ensure => "link",
		target => "/usr/lib/systemd/system/graphical.target",
	}

	# ELTDEV-782 allow eltdev control Nomad and Consul services
	file { "/etc/polkit-1/rules.d/48-nomad.rules":
                ensure => "present",
                owner => "root",
                group => "root",
                mode => "0644",
                source => "puppet:///modules/eltdev/48-nomad.rules",
        }

        file { "/etc/polkit-1/rules.d/48-consul.rules":
                ensure => "present",
                owner => "root",
                group => "root",
                mode => "0644",
                source => "puppet:///modules/eltdev/48-consul.rules",
        }

        
	Package <| |> -> augeas { "lightdm":
                context => "/files/etc/lightdm/lightdm.conf",
                changes => [
                        "set XDMCPServer/enabled true",
			"set SeatDefaults/xserver-allow-tcp true",
			"set SeatDefaults/user-session mate",
                        "set SeatDefaults/greeter-show-manual-login true",
                        "set SeatDefaults/greeter-hide-users true",
                 ],
        }
        Package <| |> -> file_line { "lightdm-2":
                path => "/etc/lightdm/lightdm-gtk-greeter.conf",
                line => "background=#0066CC",
                match => "^background=",
        }
        Package <| |> -> file_line { "lightdm-3":
                path => "/etc/lightdm/lightdm-gtk-greeter.conf",
                line => "show-indicators=~session;~a11y;~power",
                match => "show-indicators=",
        }

        # ELTDEV-328: Update ptp4l and phc2sys services startup conditions
#        Package <| |> -> file_line { "startup ptp4l conditions-1":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/ptp4l.service",
#                after => "Description=.*",
#                line => "Wants=time-sync.target",
#        }
#        Package <| |> -> file_line { "startup ptp4l conditions-2":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/ptp4l.service",
#                after => "Description=.*",
#                line => "Before=time-sync.target",
#        }
#        Package <| |> -> file_line { "startup ptp4l conditions-3":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/ptp4l.service",
#                after => "Description=.*",
#                line => "After=syslog.target network.target nss-lookup.target",
#        }

# CG. 08.10.19: To be reviewed by Javier A in REALTIME
        # ELTDEV-328: Update ptp4l and phc2sys services startup conditions
#        Package <| |> -> file_line { "startup phc2sys conditions-1":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/phc2sys.service",
#                after => "Description=.*",
#                line => "Wants=time-sync.target",
#        }
#        Package <| |> -> file_line { "startup phc2sys conditions-2":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/phc2sys.service",
#                after => "Description=.*",
#                line => "Before=time-sync.target",
#        }
#        Package <| |> -> file_line { "startup phc2sys conditions-3":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/phc2sys.service",
#                match => "^After=.*",
#                line => "After=syslog.target network.target nss-lookup.target",
#        }
#        Package <| |> -> file_line { "startup phc2sys conditions-4":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/phc2sys.service",
#                after => "Description=.*",
#                line => "Conflicts=ntpd.service chronyd.service",
#        }

# CG. 09.10.19 ntpd.service now replaced with chronyd.service
#        Package <| |> -> file_line { "startup ntpd conditions":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/ntpd.service",
#                after => "Description=.*",
#                line => "Conflicts=chronyd.service phc2sys.service",
#        }
#        Package <| |> -> file_line { "startup chronyd conditions":
#                ensure => "present",
#                path => "/usr/lib/systemd/system/chronyd.service",
#                match => "^Conflicts=.*",
#                line => "Conflicts=ntpd.service systemd-timesyncd.service phc2sys.service",
#        }

	# ELTDEV-102: Edit /etc/ptp4l.conf to set "slaveOnly 1"
        Package <| |> -> file_line { "slaveOnly-variable":
                path => "/etc/ptp4l.conf",
                line => "slaveOnly		1",
                match => "slaveOnly",
        }

        # ELTDEV-62: Add user eltdev to wireshark group
        Package <| |> -> exec {"/usr/sbin/usermod -a -G wireshark eltdev":
                onlyif => "/usr/bin/id -Gn eltdev | /bin/egrep -qv wireshark",
                require => User["eltdev"],
        }

        # ELTDEV-150: devops.local certificate management
        Package <| |> -> file { "/etc/pki/ca-trust/source/anchors/devops.local.crt":
                ensure => "present",
                owner => "root",
                group => "root",
                mode => "0644",
                source => "puppet:///modules/eltdev/devops.local.crt",
                notify => Exec["updatecatrustdevops"],
        }
        exec { "updatecatrustdevops":
                command => "/usr/bin/update-ca-trust extract",
                refreshonly => "true",
        }

        # ELTDEV-313: Xvfb on :2 to run automatic GUI tests without X
        Package <| |> -> service { "xvfb_running":
                ensure => "running",
                start => "/usr/bin/Xvfb -ac :2&",
                binary => "/usr/bin/Xvfb",
                provider => "base",
        }
        # XVfb autostart from rc.local and check that it is running
        Package <| |> -> file_line { "xvfb_rclocal":
                path => "/etc/rc.d/rc.local",
                line => "/usr/bin/Xvfb -ac :2&",
        }
        # Make sure rc.local is executable
        File_line["xvfb_rclocal"] -> file { "/etc/rc.d/rc.local":
                ensure => "present",
                mode => "0755",
        }

        Package <| |> -> file { "/etc/X11/xinit/Xclients":
                ensure => "present",
                owner => "root",
                group => "root",
                mode => "0755",
                source => "puppet:///modules/eltdev/Xclients",
        }

        group { "minio":
                ensure => "present",
                gid => "4644",
        }

        user { "minio":
                ensure => "present",
                uid => "8524",
                gid => "4644",
                comment => "MinIO Object Storage",
                require => Group["minio"],
        }

        file { "/etc/default/minio.template":
                ensure => "present",
                owner => "root",
                group => "root",
                mode => "0644",
                source => "puppet:///modules/eltdev/minio.template",
        }

}
